@@ -1,11 +1,6 @@
-/* dpmpar.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
-*/
-
 #include "cminpack.h"
 #include <float.h>
-#define real __cminpack_real__
+#include "cminpackP.h"
 
 #define double_EPSILON DBL_EPSILON
 #define double_MIN DBL_MIN
