@@ -3,6 +3,7 @@
 
 #include <stdio.h>
 #include <math.h>
+#include <assert.h>
 #include <minpack.h>
 #define real __minpack_real__
 
@@ -49,6 +50,8 @@ void fcn(const int *n, const real *x, real *fvec, int *iflag)
 
   int k;
   real one=1, temp, temp1, temp2, three=3, two=2, zero=0;
+  assert(*n == 9);
+  (void)iflag;
 
   for (k=1; k <= *n; k++)
     {
