@@ -2,6 +2,7 @@
 
 #include <stdio.h>
 #include <math.h>
+#include <assert.h>
 #include <cminpack.h>
 #define real __cminpack_real__
 
@@ -65,6 +66,8 @@ int fcn(void *p, int n, const real *x, real *fvec, int iflag)
 
   int k;
   real one=1, temp, temp1, temp2, three=3, two=2, zero=0;
+  (void)p;
+  assert(n == 9);
 
   if (iflag == 0)
     {
