@@ -2,6 +2,7 @@
 
 #include <stdio.h>
 #include <math.h>
+#include <assert.h>
 #include <cminpack.h>
 #define real __cminpack_real__
 
@@ -52,6 +53,8 @@ int fcn(void *p, int n, const real *x, real *fvec, real *fjac, int ldfjac,
 
   int j, k;
   real one=1, temp, temp1, temp2, three=3, two=2, zero=0, four=4;
+  (void)p;
+  assert(n == 9);
 
   if (iflag != 2)
     {
