@@ -2,6 +2,7 @@
 
 #include <stdio.h>
 #include <math.h>
+#include <assert.h>
 #include <cminpack.h>
 #define real __cminpack_real__
 
@@ -63,6 +64,7 @@ int  fcn(void *p, int m, int n, const real *x, real *fvec, real *fjrow, int ifla
   int i;
   real tmp1, tmp2, tmp3, tmp4;
   const real *y = ((fcndata_t*)p)->y;
+  assert(m == 15 && n == 3);
 
   if (iflag < 2)
     {
