@@ -3,21 +3,23 @@
 	-lf2c -lm   (in that order)
 */
 
-#include <math.h>
 #include "minpack.h"
+#include <math.h>
+#define real __minpack_real__
+
 #define min(a,b) ((a) <= (b) ? (a) : (b))
 #define max(a,b) ((a) >= (b) ? (a) : (b))
 #define abs(x) ((x) >= 0 ? (x) : -(x))
 #define TRUE_ (1)
 #define FALSE_ (0)
 
-/* Subroutine */ void lmstr_(void (*fcn)(const int *m, const int *n, const double *x, double *fvec,
-			  double *fjrow, int *iflag ), const int *m, const int *n, double *x, 
-	double *fvec, double *fjac, const int *ldfjac, const double *ftol,
-	const double *xtol, const double *gtol, const int *maxfev, double *
-	diag, const int *mode, const double *factor, const int *nprint, int *
-	info, int *nfev, int *njev, int *ipvt, double *qtf, 
-	double *wa1, double *wa2, double *wa3, double *wa4)
+__minpack_attr__
+void __minpack_func__(lmstr)(__minpack_decl_fcnderstr_mn__ const int *m, const int *n, real *x, 
+	real *fvec, real *fjac, const int *ldfjac, const real *ftol,
+	const real *xtol, const real *gtol, const int *maxfev, real *
+	diag, const int *mode, const real *factor, const int *nprint, int *
+	info, int *nfev, int *njev, int *ipvt, real *qtf, 
+	real *wa1, real *wa2, real *wa3, real *wa4)
 {
     /* Table of constant values */
 
@@ -34,18 +36,18 @@
 
     /* System generated locals */
     int fjac_dim1, fjac_offset, i__1, i__2;
-    double d__1, d__2, d__3;
+    real d__1, d__2, d__3;
 
     /* Local variables */
     int i__, j, l;
-    double par, sum;
+    real par, sum;
     int sing;
     int iter;
-    double temp, temp1, temp2;
+    real temp, temp1, temp2;
     int iflag;
-    double delta;
-    double ratio;
-    double fnorm, gnorm, pnorm, xnorm, fnorm1, actred, dirder, 
+    real delta;
+    real ratio;
+    real fnorm, gnorm, pnorm, xnorm, fnorm1, actred, dirder, 
 	    epsmch, prered;
 
 /*     ********** */
@@ -242,7 +244,7 @@
 
 /*     epsmch is the machine precision. */
 
-    epsmch = dpmpar_(&c__1);
+    epsmch = __minpack_func__(dpmpar)(&c__1);
 
     *info = 0;
     iflag = 0;
@@ -271,12 +273,12 @@ L20:
 /*     and calculate its norm. */
 
     iflag = 1;
-    (*fcn)(m, n, &x[1], &fvec[1], &wa3[1], &iflag);
+    fcnderstr_mn(m, n, &x[1], &fvec[1], &wa3[1], &iflag);
     *nfev = 1;
     if (iflag < 0) {
 	goto L340;
     }
-    fnorm = enorm_(m, &fvec[1]);
+    fnorm = __minpack_func__(enorm)(m, &fvec[1]);
 
 /*     initialize levenberg-marquardt parameter and iteration counter. */
 
@@ -294,7 +296,7 @@ L30:
     }
     iflag = 0;
     if ((iter - 1) % *nprint == 0) {
-	(*fcn)(m, n, &x[1], &fvec[1], &wa3[1], &iflag);
+	fcnderstr_mn(m, n, &x[1], &fvec[1], &wa3[1], &iflag);
     }
     if (iflag < 0) {
 	goto L340;
@@ -319,12 +321,12 @@ L40:
     iflag = 2;
     i__1 = *m;
     for (i__ = 1; i__ <= i__1; ++i__) {
-	(*fcn)(m, n, &x[1], &fvec[1], &wa3[1], &iflag);
+	fcnderstr_mn(m, n, &x[1], &fvec[1], &wa3[1], &iflag);
 	if (iflag < 0) {
 	    goto L340;
 	}
 	temp = fvec[i__];
-	rwupdt_(n, &fjac[fjac_offset], ldfjac, &wa3[1], &qtf[1], &temp, &wa1[
+	__minpack_func__(rwupdt)(n, &fjac[fjac_offset], ldfjac, &wa3[1], &qtf[1], &temp, &wa1[
 		1], &wa2[1]);
 	++iflag;
 /* L70: */
@@ -341,13 +343,13 @@ L40:
 	    sing = TRUE_;
 	}
 	ipvt[j] = j;
-	wa2[j] = enorm_(&j, &fjac[j * fjac_dim1 + 1]);
+	wa2[j] = __minpack_func__(enorm)(&j, &fjac[j * fjac_dim1 + 1]);
 /* L80: */
     }
     if (! sing) {
 	goto L130;
     }
-    qrfac_(n, n, &fjac[fjac_offset], ldfjac, &c_true, &ipvt[1], n, &wa1[1], &
+    __minpack_func__(qrfac)(n, n, &fjac[fjac_offset], ldfjac, &c_true, &ipvt[1], n, &wa1[1], &
 	    wa2[1], &wa3[1]);
     i__1 = *n;
     for (j = 1; j <= i__1; ++j) {
@@ -399,7 +401,7 @@ L150:
 	wa3[j] = diag[j] * x[j];
 /* L160: */
     }
-    xnorm = enorm_(n, &wa3[1]);
+    xnorm = __minpack_func__(enorm)(n, &wa3[1]);
     delta = *factor * xnorm;
     if (delta == 0.) {
 	delta = *factor;
@@ -462,7 +464,7 @@ L240:
 
 /*           determine the levenberg-marquardt parameter. */
 
-    lmpar_(n, &fjac[fjac_offset], ldfjac, &ipvt[1], &diag[1], &qtf[1], &delta,
+    __minpack_func__(lmpar)(n, &fjac[fjac_offset], ldfjac, &ipvt[1], &diag[1], &qtf[1], &delta,
 	     &par, &wa1[1], &wa2[1], &wa3[1], &wa4[1]);
 
 /*           store the direction p and x + p. calculate the norm of p. */
@@ -474,7 +476,7 @@ L240:
 	wa3[j] = diag[j] * wa1[j];
 /* L250: */
     }
-    pnorm = enorm_(n, &wa3[1]);
+    pnorm = __minpack_func__(enorm)(n, &wa3[1]);
 
 /*           on the first iteration, adjust the initial step bound. */
 
@@ -485,12 +487,12 @@ L240:
 /*           evaluate the function at x + p and calculate its norm. */
 
     iflag = 1;
-    (*fcn)(m, n, &wa2[1], &wa4[1], &wa3[1], &iflag);
+    fcnderstr_mn(m, n, &wa2[1], &wa4[1], &wa3[1], &iflag);
     ++(*nfev);
     if (iflag < 0) {
 	goto L340;
     }
-    fnorm1 = enorm_(m, &wa4[1]);
+    fnorm1 = __minpack_func__(enorm)(m, &wa4[1]);
 
 /*           compute the scaled actual reduction. */
 
@@ -516,7 +518,7 @@ L240:
 	}
 /* L270: */
     }
-    temp1 = enorm_(n, &wa3[1]) / fnorm;
+    temp1 = __minpack_func__(enorm)(n, &wa3[1]) / fnorm;
     temp2 = sqrt(par) * pnorm / fnorm;
 /* Computing 2nd power */
     d__1 = temp1;
@@ -584,7 +586,7 @@ L300:
 	fvec[i__] = wa4[i__];
 /* L320: */
     }
-    xnorm = enorm_(n, &wa2[1]);
+    xnorm = __minpack_func__(enorm)(n, &wa2[1]);
     fnorm = fnorm1;
     ++iter;
 L330:
@@ -641,7 +643,7 @@ L340:
     }
     iflag = 0;
     if (*nprint > 0) {
-	(*fcn)(m, n, &x[1], &fvec[1], &wa3[1], &iflag);
+	fcnderstr_mn(m, n, &x[1], &fvec[1], &wa3[1], &iflag);
     }
     return;
 
